package com.yixin.ms.service.impl;


import cn.hutool.core.lang.UUID;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.yixin.ms.boot.restful.ServiceException;
import com.yixin.ms.boot.uitls.OkHttpUtils;
import com.yixin.ms.boot.uitls.RedisUtil;
import com.yixin.ms.model.dto.ShortTermDTO;
import com.yixin.ms.model.vo.HealtCodeNucleinVO;
import com.yixin.ms.model.vo.HealtCodeTypeVO;
import com.yixin.ms.model.vo.HealtCodeUserVO;
import com.yixin.ms.service.HealthCodeService;
import jdk.nashorn.internal.objects.NativeUint8Array;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.util.List;


@Slf4j
@Service
public class HealthCodeServiceImpl implements HealthCodeService {


    @Autowired
    private RedisUtil redisUtil;

    @Async
    @Override
    public HealtCodeUserVO getShortTermCertificate(ShortTermDTO shortTermDTO) {

        try {
            String shortTermUser = getShortTermUser(shortTermDTO.getIdNumber(), shortTermDTO.getName());
            if (StringUtils.isBlank(shortTermUser)) {
                return null;
            }
            JSONObject jsonObject = JSON.parseObject(shortTermUser);
            if (StringUtils.equals("00", jsonObject.getString("error_code"))) {
                HealtCodeUserVO healtCodeUserVO = new HealtCodeUserVO();
                healtCodeUserVO.setData(JSON.parseArray(jsonObject.getJSONArray("data").toJSONString(), HealtCodeTypeVO.class));
                healtCodeUserVO.setNuclein(JSON.parseArray(jsonObject.getJSONArray("nuclein").toJSONString(), HealtCodeNucleinVO.class));
                healtCodeUserVO.setVaccineNum(jsonObject.getString("vaccine_num"));
                return healtCodeUserVO;
            } else {
                throw new ServiceException(jsonObject.getString("msg"));
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new ServiceException("健康码平台异常");
        }

    }

    @Override
    public String addToken(String token) {
        String s = "hh_token_" + UUID.randomUUID();
        boolean hanghui = redisUtil.set(s, s);
        if (hanghui) {
            return s;
        } else {
            throw new ServiceException("体检失败");
        }

    }

    @Override
    public Boolean deleteToken(String token) {
        return redisUtil.delete(token);
    }


    public String getShortTermUser(String sfzh, String name) throws Exception {
        log.info("健康码传参，身份证{} 姓名 {}", sfzh, name);
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("sfzh", sfzh);
        jsonObject.put("xm", name);
        String sync = OkHttpUtils.builder().url("http://115.236.38.205:8903/id/hvn")
                .addHeader("Content-Type", "application/json; charset=utf-8")
                .localPost(jsonObject.toJSONString())
                .sync();
        log.info("健康码返回结果，{}", sync);
        return sync;
    }
}

